﻿Fluke Calibration                                           MET/CAL Procedure
=============================================================================
INSTRUMENT:            HP 8647A: (2 year) VER IEEE /8902A,8903B,8560
DATE:                  2019-06-19 10:56:08
AUTHOR:                Fluke
REVISION:              $Revision: 18978 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       314
CONFIGURATION:         HP 8902A
CONFIGURATION:         HP 8903B
CONFIGURATION:         HP 8560
STANDARD:              HP 11722A
=============================================================================
#
#  Procedure Author:
#        DFM
#
#  Source:
#        HP 8647A Operation and Service Guide, Part No. 08647-90006,
#        Third Edition, July 1993
#
#  Compatibility:
#        MET/CAL 7.01 SP1 or later
#
#  Additional Equipment Required:
#        HP/Agilent 11722A Sensor Module
#        Cable assy., 12", BNC(m)-(m), 50 Ohm
#        Cable assy., 36", Type "N"(m)-(m), 50 Ohm, 2 ea.
#        Adapter, Type "N"(f) to BNC(m)
#        8903B Option 051 (CCITT Weighting filter)
#
#  This procedure is intended for use with MET/CAL® calibration software;
#  the terms and conditions set forth in your MET/CAL license apply to this
#  procedure.
#
#  Due to Fluke's policy of continuously updating our products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, Fluke cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
#  Global String Variables:
#
#       S[1] - S[5] populated by subprocedure, "Sub IEEE-488.2 Identification
#                   Query (*IDN?) IEEE"
#
#       S[1] = Manufacturer
#       S[2] = Model
#       S[3] = Serial Number
#       S[4] = Firmware Level or equivalent
#       S[5] = Firmware Level; stripped of blank spaces, if present
#
#       S[6] = Indicates execution mode selected, "TUR" or "MU".
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON
  1.001  ASK-   R   Q N              P J             C            A        W
  1.002  ASK+           K

  1.003  JMPL         PROC_START
  1.004  8902         *                                                 S
  1.005  8903         *                                                 S
  1.006  8560         *                                                 S

  1.007  LABEL        PROC_START
# Verify MET/CAL version compatibility.
  1.008  IF           VERS() < 7.01
  1.009  DISP         This procedure requires MET/CAL 7.01 SP1 or later.
  1.010  JMPL         END
  1.011  ENDIF

# Test to ensure MET/CAL initialization file parameter "acc_check" = "yes"
  1.012  IF           ZCMPI(INI("startup", "acc_check"), "no")
  1.013  HEAD         INCORRECT MET/CAL® INITIALIZATION FILE SETTING!
  1.014  DISP         The file parameter setting is: "acc_check=no"
  1.014  DISP
  1.014  DISP         For correct procedure execution, this parameter
  1.014  DISP         MUST be set to: "acc_check=yes"
  1.014  DISP
  1.014  DISP         Select "Advance" to terminate the procedure, exit
  1.014  DISP         MET/CAL®, change the initialization file parameter,
  1.014  DISP         restart MET/CAL, then restart the procedure.
  1.015  END
  1.016  ENDIF

  1.017  HEAD         HP 8560 ACCURACY FILE REQUIREMENTS
  1.018  DISP         This procedure requires HP 8560 accuracy file
  1.018  DISP         "8560.acc" revision 1.11 or later.
  1.018  DISP
  1.018  DISP         Please confirm the revision of the accuracy
  1.018  DISP         file in use prior to proceeding.
  1.018  DISP
  1.018  DISP         Visit the website at: http://support.fluke.com
  1.018  DISP         for the latest accuracy file, if necessary.

  1.019  HEAD         COPYRIGHT NOTICE
  1.020  DISP         [32]               PLEASE NOTE!
  1.020  DISP         This procedure is © 2004, Fluke Corporation.
  1.020  DISP         All rights reserved.

  1.021  HEAD         INITIAL INFORMATION
  1.022  OPBR         Do you want this procedure to PAUSE on failed tests?

  1.023  IF           MEM1 > 0
# Set ASK flags to enable Post Test box with "Cancel" option on fail.
  1.024  ASK+                                          X
  1.025  ASK-                                                     F
  1.026  ENDIF

# Initial hook-up information.
  1.027  HEAD         PRELIMINARY INSTRUCTIONS
  1.028  DISP         Ensure that the UUT REMOTE PORT is set for GPIB
  1.028  DISP         operation (the address is not important, as long
  1.028  DISP         as it is not (0) zero).

  1.029  DISP         Prior to beginning verification, a UUT warm-up time
  1.029  DISP         of 30 minutes (minimum) must have been allowed to
  1.029  DISP         elapse.

  1.030  DISP         Throughout the procedure, exercise care when making
  1.030  DISP         connections or disconnections. Tighten/loosen Type
  1.030  DISP         "N" connectors by turning the collar, NOT the body.
  1.030  DISP         Rotating the connector body will damage the center
  1.030  DISP         pin, causing potentially expensive repairs as well
  1.030  DISP         as seriously degrading measurement results.

  1.031  HEAD         PROCEDURE EXECUTION INFORMATION
  1.032  DISP         This procedure supports the reporting of both Test
  1.032  DISP         Uncertainty Ratio (TUR) or measurement uncertainty.
  1.032  DISP
  1.032  DISP         When computing measurement uncertainty, best results
  1.032  DISP         are obtained when multiple readings are taken at each
  1.032  DISP         data point.  This is accomplished at the expense of
  1.032  DISP         increased procedure execution time.
  1.033  OPBR         Do you wish this procedure to generate 'best case'
  1.033  OPBR         measurement uncertainty data (longer running time)?
  1.033  OPBR
  1.033  OPBR         (Pressing "No" will cause procedure execution to be
  1.033  OPBR         optimized for the calculation of Test Uncertainty
  1.033  OPBR         Ratios (TUR) and shorter running time.)

  1.034  IF           MEM1 > 0
# Set VSET parameters for optimum measurement uncertainty operation.
  1.035  VSET         NTHROW = 1 NMEAS = 5 MEASURE_ONLY = Yes NSD = 3
# Specify measurement uncertainty mode acronym for later use.
  1.036  MATH         S[6] = "MU"
  1.037  ELSE
# Set VSET parameters for optimum TUR operation.
  1.038  VSET         NTHROW = 0 NMEAS = 1 MEASURE_ONLY = Yes
# Specify test uncertainty ratio (TUR) mode acronym for later use.
  1.039  MATH         S[6] = "TUR"
  1.040  ENDIF

  1.041  HEAD         EQUIPMENT REQUIREMENTS
  1.042  OPBR         Do you want to REVIEW the list of additional
  1.042  OPBR         equipment and/or accessories required?

  1.043  IF           MEM1 > 0
  1.044  DISP         Additional equipment/accessories required:
  1.044  DISP
  1.044  DISP         - HP/Agilent 11722A Sensor Module, calibrated
  1.044  DISP         - 8903B Option 051 (CCITT Weighting filter)
  1.044  DISP         - Cable assembly, 12", BNC(m)-(m), 50 Ohm
  1.044  DISP         - Cable assembly, 36", BNC(m)-(m), 50 Ohm, 2 ea.
  1.044  DISP         - Adapter, coaxial, Type "N"(f) to BNC(m), 2 ea.
  1.044  DISP         - Adapter, tee, coaxial, BNC(f)-(m)-(f)
  1.045  ENDIF

  1.046  OPBR         This procedure REQUIRES that the 8903B Option 051
  1.046  OPBR         (CCITT WEIGHTING filter) be installed in the 8903B
  1.046  OPBR         "Right-Most Optional Plug-In Filter" slot.
  1.046  OPBR
  1.046  OPBR         Is the above requirement satisfied?

  1.047  IF           MEM1 < 0
  1.048  DISP         PROCEDURE ABORTED!
  1.049  END
  1.050  ENDIF

# Query UUT for Mfr., Model, Serial Number, and firmware values.
  1.051  CALL         Sub IEEE-488.2 Identification Query (*IDN?) IEEE
# Using model number info returned in sub, check for correct UUT.

  1.052  IF           ZCMPI(S[2], "8647A") == 0
  1.053  HEAD         INCORRECT UUT CONNECTED!
  1.054  DISP         This procedure is written to support the
  1.054  DISP         verification of the 8647A.
  1.054  DISP
  1.054  DISP         The UUT connected is an[S2].
  1.055  END
  1.056  ENDIF

  1.057  HEAD         INITIAL CONNECTIONS
  1.058  DISP         Connect HP 8902A MODULATION OUTPUT/AUDIO INPUT to
  1.058  DISP         HP 8903B INPUT 20 Hz - 100 kHz HIGH using the 12"
  1.058  DISP         BNC(m)-(m) cable assembly.
  1.058  DISP
  1.058  DISP         Ensure the HP 8903B INPUT (right) FLOAT switch is
  1.058  DISP         set for 'grounded' operation.

  1.059  DISP         Using a BNC(f)-(m)-(f) tee, connect the UUT 10 MHz
  1.059  DISP         REF OUTPUT (rear panel) to the HP 8902A TIMEBASE
  1.059  DISP         10 MHz INPUT (rear panel) and HP 8560A 10 MHz REF
  1.059  DISP         IN/OUT (rear panel) using the 36" BNC(m)-(m) cable
  1.059  DISP         assemblies.

  1.060  DISP         Connect the HP 11722A Sensor Module to the HP 8902A
  1.060  DISP         SENSOR (multi-pin) and INPUT 50 Ohm (Type "N") jacks.
  1.060  DISP
  1.060  DISP         [32]                     NOTE
  1.060  DISP         Manipulating the 11722A Sensor Module may cause its
  1.060  DISP         connection to the 8902A INPUT 50 Ohm Type "N" jack
  1.060  DISP         to work loose. Ensure this connection remains snug
  1.060  DISP         throughout to avoid measurement degradation.

  1.061  HEAD         PRELIMINARY OPERATIONS
  1.062  OPBR         Have the Calibration Factors for the Sensor Module
  1.062  OPBR         being used previously been entered into the 8902A?
  1.062  OPBR
  1.062  OPBR         (Answering "No" will also allow you to REVIEW the
  1.062  OPBR         existing cal factors.)

  1.063  IF           MEM1 < 0
  1.064  CALL         Sub 8902A Cal Factor Utility
  1.065  ENDIF

  1.066  ASK-                              U
  1.067  HEAD         HP 8902A RF POWER CALIBRATION
  1.068  DISP         Connect the 11722A Sensor Module to the HP 8902A
  1.068  DISP         CALIBRATION RF POWER OUTPUT.
  1.069  WAIT         -t 30 Thermal emfs dissipating...
  1.070  8902         1mW                          50MH              CP N

  1.071  HEAD         HP 8902A AM CALIBRATION
  1.072  DISP         Move the HP 11722A Sensor Module from the HP 8902A
  1.072  DISP         CALIBRATION RF POWER OUTPUT to the CALIBRATION
  1.072  DISP         AM/FM OUTPUT.
  1.073  8902         100.00pct                                      CA N

  1.074  HEAD         HP 8902A FM CALIBRATION
  1.075  8902         100.00pct                                      CF N

  1.076  ASK+                              U
  1.077  HEAD         HP 8902A RF POWER, AM, and FM CALIBRATIONS COMPLETED
  1.078  DISP         Disconnect the HP 11722A Sensor Module from the
  1.078  DISP         HP 8902A CALIBRATION AM/FM OUTPUT and connect it
  1.078  DISP         to the UUT RF OUTPUT 50 Ohms.

  1.079  IF           ZCMPI(S[6], "MU")
  1.080  DISP         The next routine operator intervention occurs in
  1.080  DISP         approximately 120 minutes.
  1.081  ELSEIF       ZCMPI(S[6], "TUR")
  1.082  DISP         The next routine operator intervention occurs in
  1.083  DISP         approximately 31 minutes.
  1.084  ENDIF

# Ensure UUT reset to default conditions prior to beginning tests.
  1.085  SCPI         *RST
  1.086  CALL         Sub HP 8647A (2 yr) FM Accuracy VER /8902,8903

  1.087  CALL         Sub HP 8647A (2 yr) FM Distortion VER /8902,8903

  1.088  CALL         Sub HP 8647A (2 yr) AM Accuracy VER /8902,8903

  1.089  CALL         Sub HP 8647A (2 yr) AM Distortion VER /8902,8903

  1.090  CALL         Sub HP 8647A (2 yr) PM Accuracy VER /8902,8903

  1.091  CALL         Sub HP 8647A (2 yr) PM Distortion VER /8902,8903

  1.092  CALL         Sub HP 8647A (2 yr) Residual FM VER /8902,8903
  1.093  JMPL         DC_FM

  1.094  LABEL        HARMONICS
  1.095  HEAD         HARMONICS PERFORMANCE TEST
  1.096  DISP         Disconnect the UUT RF OUTPUT 50 Ohms from the
  1.096  DISP         PM 6680 Channel "C" input.

# Determine specific model of 8560-series analyzer is being used.
  1.097  CALL         Sub Specify HP856x Model Number
  1.098  DISP         Connect the UUT RF OUTPUT to the [MEM2]
  1.098  DISP         Spectrum Analyzer RF INPUT.

  1.099  CALL         Sub HP 8647A (2 yr) Harmonics VER /8560

  1.100  CALL         Sub HP 8647A (2 yr) Spurious VER /8560

  1.101  CALL         Sub Specify HP856x Model Number
  1.102  DISP         Disconnect the UUT RF OUTPUT from the [MEM2]
  1.102  DISP         Spectrum Analyzer RF INPUT.

  1.103  JMPL         END

  1.104  LABEL        DC_FM
  1.105  CALL         Sub HP 8647A (2 yr) DC FM Freq Error VER /8902

# Query UUT for installed timebase option.
  1.106  SCPI         *OPT?[I$]

  1.107  IF           ZCMPI(FLD(MEM2, 1, ","), "HIGH STABILITY REF")
  1.108  CALL         Sub HP 8647A (2 yr) CW Frequency Accy VER /8902
  1.109  ENDIF

  1.110  LABEL        RF_LEVEL
  1.111  STD          HP 11722A
  1.112  CALL         Sub HP 8647A (2 yr) RF Level VER /8902,11722
  1.113  JMPL         HARMONICS

  1.114  LABEL        END
  1.115  HEAD
  1.116  END
